# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`taiga`](#taiga): Install both Taiga front, back and setup an apache Virtual Host
* [`taiga::back`](#taigaback): Install Taiga back
* [`taiga::front`](#taigafront): Install taiga front
* [`taiga::vhost`](#taigavhost): Configure an apache Virtual Host for taiga

#### Private Classes

* `taiga::back::config`: Configure Taiga back
* `taiga::back::cron`: Setup crontab
* `taiga::back::database`: Configure Taiga back database
* `taiga::back::dependencies`: Configure Taiga back dependencies
* `taiga::back::install`: Install Taiga back
* `taiga::back::ldap`: Manage Taiga back LDAP configuration
* `taiga::back::migrate`: Perform Taiga back migrations
* `taiga::back::repo`: Manage the Taiga back repository
* `taiga::back::seed`: Seed Taiga back
* `taiga::back::user`: Manage the Taiga back user
* `taiga::front::config`: Manage Taiga front config
* `taiga::front::repo`: Manage the Taiga front repository

### Defined types

#### Public Defined types


#### Private Defined types

* `taiga::back::manage`: Allow running actions in Taiga back environment

### Tasks

* [`version`](#version): Retrieve Taiga back and front versions

## Classes

### <a name="taiga"></a>`taiga`

Install both Taiga front, back and setup an apache Virtual Host

#### Parameters

The following parameters are available in the `taiga` class:

* [`hostname`](#hostname)
* [`back_secret_key`](#back_secret_key)
* [`back_db_password`](#back_db_password)
* [`protocol`](#protocol)
* [`default_language`](#default_language)
* [`repo_ensure`](#repo_ensure)
* [`repo_revision`](#repo_revision)
* [`back_directory`](#back_directory)
* [`venv_directory`](#venv_directory)
* [`front_directory`](#front_directory)
* [`back_user`](#back_user)
* [`public_register_enabled`](#public_register_enabled)
* [`gravatar`](#gravatar)
* [`ldap_server`](#ldap_server)
* [`ldap_port`](#ldap_port)
* [`ldap_bind_dn`](#ldap_bind_dn)
* [`ldap_bind_password`](#ldap_bind_password)
* [`ldap_search_base`](#ldap_search_base)
* [`ldap_search_property`](#ldap_search_property)
* [`ldap_search_suffix`](#ldap_search_suffix)
* [`ldap_email_property`](#ldap_email_property)
* [`ldap_full_name_property`](#ldap_full_name_property)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)
* [`ssl_chain`](#ssl_chain)
* [`change_notification_min_interval`](#change_notification_min_interval)
* [`default_project_slug_prefix`](#default_project_slug_prefix)

##### <a name="hostname"></a>`hostname`

Data type: `String[1]`

Hostname that will be used to reach the Taiga instance.

##### <a name="back_secret_key"></a>`back_secret_key`

Data type: `String[1]`

A secret key passed to the `SECRET_KEY` setting in taiga-back configuration. (A 60 characters random string should be a good start).

##### <a name="back_db_password"></a>`back_db_password`

Data type: `String[1]`

Sets the database password. It is currently not used but still has to be provided.

##### <a name="protocol"></a>`protocol`

Data type: `Enum['http', 'https']`

Protocol to be used.

Default value: `'https'`

##### <a name="default_language"></a>`default_language`

Data type: `String[2, 2]`

Default language.

Default value: `'en'`

##### <a name="repo_ensure"></a>`repo_ensure`

Data type: `Enum['present', 'latest']`

Ensure value for Taiga's vcs repository.

Default value: `'present'`

##### <a name="repo_revision"></a>`repo_revision`

Data type: `String[1]`

Revision for Taiga's vcs repository.

Default value: `'stable'`

##### <a name="back_directory"></a>`back_directory`

Data type: `Stdlib::Absolutepath`

Directory where is installed the backend of Taiga.

Default value: `'/srv/www/taiga-back'`

##### <a name="venv_directory"></a>`venv_directory`

Data type: `Stdlib::Absolutepath`

Default where is installed python dependencies.

Default value: `'/srv/www/taiga-venv'`

##### <a name="front_directory"></a>`front_directory`

Data type: `Stdlib::Absolutepath`

Directory where is installed the frontend of Taiga.

Default value: `'/srv/www/taiga-front'`

##### <a name="back_user"></a>`back_user`

Data type: `String[1]`

Name of the user running the backend daemon.

Default value: `'taiga'`

##### <a name="public_register_enabled"></a>`public_register_enabled`

Data type: `Boolean`

Enable anyone to register on this instance.

Default value: ``true``

##### <a name="gravatar"></a>`gravatar`

Data type: `Boolean`

Use gravatar.

Default value: ``true``

##### <a name="ldap_server"></a>`ldap_server`

Data type: `Optional[String[1]]`

LDAP server.

Default value: ``undef``

##### <a name="ldap_port"></a>`ldap_port`

Data type: `Integer`

LDAP port.

Default value: `389`

##### <a name="ldap_bind_dn"></a>`ldap_bind_dn`

Data type: `Optional[String[1]]`

DN to use for LDAP authentication.

Default value: ``undef``

##### <a name="ldap_bind_password"></a>`ldap_bind_password`

Data type: `Optional[String[1]]`

Password to use for LDAP authentication.

Default value: ``undef``

##### <a name="ldap_search_base"></a>`ldap_search_base`

Data type: `String[1]`

Search base for users.

Default value: `'ou=people,dc=example,dc=com'`

##### <a name="ldap_search_property"></a>`ldap_search_property`

Data type: `String[1]`

Property holding users login.

Default value: `'uid'`

##### <a name="ldap_search_suffix"></a>`ldap_search_suffix`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_email_property"></a>`ldap_email_property`

Data type: `String[1]`

Property holding users e-mail.

Default value: `'mail'`

##### <a name="ldap_full_name_property"></a>`ldap_full_name_property`

Data type: `String[1]`

Property holding users full name.

Default value: `'cn'`

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Optional[Stdlib::Absolutepath]`

Certificate to use for apache VirtualHost.

Default value: ``undef``

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Optional[Stdlib::Absolutepath]`

Key to use for apache VirtualHost.

Default value: ``undef``

##### <a name="ssl_chain"></a>`ssl_chain`

Data type: `Optional[Stdlib::Absolutepath]`

Certificate chain to use for apache VirtualHost.

Default value: ``undef``

##### <a name="change_notification_min_interval"></a>`change_notification_min_interval`

Data type: `Optional[Integer]`

Interval for sending change notifications.

Default value: ``undef``

##### <a name="default_project_slug_prefix"></a>`default_project_slug_prefix`

Data type: `Optional[Boolean]`

Add username to project slug

Default value: ``undef``

### <a name="taigaback"></a>`taiga::back`

Install Taiga back

#### Parameters

The following parameters are available in the `taiga::back` class:

* [`front_hostname`](#front_hostname)
* [`front_protocol`](#front_protocol)
* [`back_hostname`](#back_hostname)
* [`back_protocol`](#back_protocol)
* [`secret_key`](#secret_key)
* [`db_password`](#db_password)
* [`dependencies`](#dependencies)
* [`db_name`](#db_name)
* [`db_user`](#db_user)
* [`user`](#user)
* [`repo_ensure`](#repo_ensure)
* [`repo_revision`](#repo_revision)
* [`install_dir`](#install_dir)
* [`venv_dir`](#venv_dir)
* [`public_register_enabled`](#public_register_enabled)
* [`ldap_enable`](#ldap_enable)
* [`ldap_server`](#ldap_server)
* [`ldap_port`](#ldap_port)
* [`ldap_bind_dn`](#ldap_bind_dn)
* [`ldap_bind_password`](#ldap_bind_password)
* [`ldap_search_base`](#ldap_search_base)
* [`ldap_search_property`](#ldap_search_property)
* [`ldap_search_suffix`](#ldap_search_suffix)
* [`ldap_email_property`](#ldap_email_property)
* [`ldap_full_name_property`](#ldap_full_name_property)
* [`email_use_tls`](#email_use_tls)
* [`email_host`](#email_host)
* [`email_port`](#email_port)
* [`email_user`](#email_user)
* [`email_password`](#email_password)
* [`change_notification_min_interval`](#change_notification_min_interval)
* [`default_project_slug_prefix`](#default_project_slug_prefix)

##### <a name="front_hostname"></a>`front_hostname`

Data type: `String[1]`

Hostname used to reach the frontend.

##### <a name="front_protocol"></a>`front_protocol`

Data type: `Enum['http', 'https']`

Protocol used to reach the frontend.

##### <a name="back_hostname"></a>`back_hostname`

Data type: `String[1]`

Hostname used to reach the backend.

##### <a name="back_protocol"></a>`back_protocol`

Data type: `Enum['http', 'https']`

Protocol used to reach the backend.

##### <a name="secret_key"></a>`secret_key`

Data type: `String[1]`

A secret key passed to the `SECRET_KEY` setting in taiga-back configuration. (A 60 characters random string should be a good start).

##### <a name="db_password"></a>`db_password`

Data type: `String[1]`

Sets the database password. It is currently not used but still has to be provided.

##### <a name="dependencies"></a>`dependencies`

Data type: `Array[String[1]]`

Extra depepdencies.

##### <a name="db_name"></a>`db_name`

Data type: `String[1]`

Name of the database.

Default value: `'taiga'`

##### <a name="db_user"></a>`db_user`

Data type: `String[1]`

User of the database.

Default value: `'taiga'`

##### <a name="user"></a>`user`

Data type: `String[1]`

Name of the user running the backend daemon.

Default value: `'taiga'`

##### <a name="repo_ensure"></a>`repo_ensure`

Data type: `Enum['present', 'latest']`

Ensure value for Taiga's vcs repository.

Default value: `'present'`

##### <a name="repo_revision"></a>`repo_revision`

Data type: `String[1]`

Revision for Taiga's vcs repository.

Default value: `'stable'`

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

Directory where is installed the backend of Taiga.

Default value: `'/srv/www/taiga-back'`

##### <a name="venv_dir"></a>`venv_dir`

Data type: `Stdlib::Absolutepath`

Directory where is installed Taiga pyhton dependencies.

Default value: `'/srv/www/taiga-venv'`

##### <a name="public_register_enabled"></a>`public_register_enabled`

Data type: `Boolean`

Enable anyone to register on this instance.

Default value: ``true``

##### <a name="ldap_enable"></a>`ldap_enable`

Data type: `Boolean`

Enable the LDAP client.

Default value: ``false``

##### <a name="ldap_server"></a>`ldap_server`

Data type: `Optional[String[1]]`

LDAP server.

Default value: ``undef``

##### <a name="ldap_port"></a>`ldap_port`

Data type: `Integer`

LDAP port.

Default value: `389`

##### <a name="ldap_bind_dn"></a>`ldap_bind_dn`

Data type: `Optional[String[1]]`

DN to use for LDAP authentication.

Default value: ``undef``

##### <a name="ldap_bind_password"></a>`ldap_bind_password`

Data type: `Optional[String[1]]`

Password to use for LDAP authentication.

Default value: ``undef``

##### <a name="ldap_search_base"></a>`ldap_search_base`

Data type: `String[1]`

Search base for users.

Default value: `'ou=people,dc=example,dc=com'`

##### <a name="ldap_search_property"></a>`ldap_search_property`

Data type: `String[1]`

Property holding users login.

Default value: `'uid'`

##### <a name="ldap_search_suffix"></a>`ldap_search_suffix`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ldap_email_property"></a>`ldap_email_property`

Data type: `String[1]`

Property holding users e-mail.

Default value: `'mail'`

##### <a name="ldap_full_name_property"></a>`ldap_full_name_property`

Data type: `String[1]`

Property holding users full name.

Default value: `'cn'`

##### <a name="email_use_tls"></a>`email_use_tls`

Data type: `Boolean`

Use TLS to connect to the mail server.

Default value: ``false``

##### <a name="email_host"></a>`email_host`

Data type: `String[1]`

Hostname of the mail server.

Default value: `'localhost'`

##### <a name="email_port"></a>`email_port`

Data type: `Integer`

Port of the mail server.

Default value: `25`

##### <a name="email_user"></a>`email_user`

Data type: `Optional[String[1]]`

Username to authenticate on the mail server.

Default value: ``undef``

##### <a name="email_password"></a>`email_password`

Data type: `Optional[String[1]]`

Password to authenticate on the mail server.

Default value: ``undef``

##### <a name="change_notification_min_interval"></a>`change_notification_min_interval`

Data type: `Optional[Integer]`

Interval for sending change notifications.

Default value: ``undef``

##### <a name="default_project_slug_prefix"></a>`default_project_slug_prefix`

Data type: `Optional[Boolean]`

Add username to project slug

Default value: ``undef``

### <a name="taigafront"></a>`taiga::front`

Install taiga front

#### Parameters

The following parameters are available in the `taiga::front` class:

* [`back_hostname`](#back_hostname)
* [`back_protocol`](#back_protocol)
* [`events`](#events)
* [`user`](#user)
* [`repo_ensure`](#repo_ensure)
* [`repo_revision`](#repo_revision)
* [`install_dir`](#install_dir)
* [`default_language`](#default_language)
* [`public_register_enabled`](#public_register_enabled)
* [`ldap_enable`](#ldap_enable)
* [`gravatar`](#gravatar)

##### <a name="back_hostname"></a>`back_hostname`

Data type: `String[1]`

Hostname used to reach the backend.

##### <a name="back_protocol"></a>`back_protocol`

Data type: `Enum['http', 'https']`

Protocol used to reach the backend.

##### <a name="events"></a>`events`

Data type: `Boolean`



Default value: ``false``

##### <a name="user"></a>`user`

Data type: `String[1]`

Name of the user owning the files of the frontend.

Default value: `'nobody'`

##### <a name="repo_ensure"></a>`repo_ensure`

Data type: `Enum['present', 'latest']`

Ensure value for Taiga's vcs repository.

Default value: `'present'`

##### <a name="repo_revision"></a>`repo_revision`

Data type: `String[1]`

Revision for Taiga's vcs repository.

Default value: `'stable'`

##### <a name="install_dir"></a>`install_dir`

Data type: `Stdlib::Absolutepath`

Directory where is installed the frontend of Taiga.

Default value: `'/srv/www/taiga-front'`

##### <a name="default_language"></a>`default_language`

Data type: `String[2, 2]`

Default language.

Default value: `'en'`

##### <a name="public_register_enabled"></a>`public_register_enabled`

Data type: `Boolean`

Enable anyone to register on this instance.

Default value: ``true``

##### <a name="ldap_enable"></a>`ldap_enable`

Data type: `Boolean`

Enable the LDAP client.

Default value: ``false``

##### <a name="gravatar"></a>`gravatar`

Data type: `Boolean`

Use gravatar.

Default value: ``true``

### <a name="taigavhost"></a>`taiga::vhost`

Configure an apache Virtual Host for taiga

#### Parameters

The following parameters are available in the `taiga::vhost` class:

* [`protocol`](#protocol)
* [`hostname`](#hostname)
* [`back_directory`](#back_directory)
* [`venv_directory`](#venv_directory)
* [`front_directory`](#front_directory)
* [`back_user`](#back_user)
* [`ssl_cert`](#ssl_cert)
* [`ssl_key`](#ssl_key)
* [`ssl_chain`](#ssl_chain)

##### <a name="protocol"></a>`protocol`

Data type: `Enum['http', 'https']`

Protocol to be used.

##### <a name="hostname"></a>`hostname`

Data type: `String[1]`

Hostname that will be used to reach the Taiga instance.

##### <a name="back_directory"></a>`back_directory`

Data type: `Stdlib::Absolutepath`

Directory where is installed the backend of Taiga.

##### <a name="venv_directory"></a>`venv_directory`

Data type: `Stdlib::Absolutepath`

Directory where is installed python dependencies.

##### <a name="front_directory"></a>`front_directory`

Data type: `Stdlib::Absolutepath`

Directory where is installed the frontend of Taiga.

##### <a name="back_user"></a>`back_user`

Data type: `String[1]`

Name of the user running the backend daemon.

##### <a name="ssl_cert"></a>`ssl_cert`

Data type: `Optional[String[1]]`

Certificate to use for apache VirtualHost.

Default value: ``undef``

##### <a name="ssl_key"></a>`ssl_key`

Data type: `Optional[String[1]]`

Key to use for apache VirtualHost.

Default value: ``undef``

##### <a name="ssl_chain"></a>`ssl_chain`

Data type: `Optional[String[1]]`

Certificate chain to use for apache VirtualHost.

Default value: ``undef``

## Defined types

## Tasks

### <a name="version"></a>`version`

Retrieve Taiga back and front versions

**Supports noop?** false

#### Parameters

##### `backend_directory`

Data type: `String[1]`

Backend directory

##### `frontend_directory`

Data type: `String[1]`

Frontend directory

